<?php
/**
 * Plugin Name: Customise Maximum Bookings Per Slot
 * Plugin URI: https://pluginhive.com/
 * Description: An Add-on for PluginHive Woocommerce Booking and Appointments plugin to set maximum number of bookings per slot based on custom start and end date.
 * Version: 1.0.1
 * Author: pluginhive
 * Author URI: https://pluginhive.com
 * Text Domain: bookings-and-appointments-for-woocommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! defined( 'PH_BOOKINGS_CUSTOMISE_MAX_BOOKING_PLUGIN_FILE' ) )
	define( 'PH_BOOKINGS_CUSTOMISE_MAX_BOOKING_PLUGIN_FILE', __FILE__ );

	define( 'PH_MAX_BOOKINGS_SETTING_ID', 'ph_booking_customize_maximum_booking_per_slot' );

	function ph_bookings_activation_check_for_customise_maximum_booking_per_slot_addon(){
		if ( !is_plugin_active('ph-bookings-appointments-woocommerce-premium/ph-bookings-appointments-woocommerce-premium.php') ){
			deactivate_plugins( basename( __FILE__ ) );
			wp_die( __("Oops! You tried installing the Customise Maximum Bookings Per Slot Plugin without activating Bookings and Appointments For WooCommerce Premium Plugin. Kindly activate <b>Bookings and Appointments For WooCommerce Premium Plugin</b> and then try again", "bookings-and-appointments-for-woocommerce" ), "", array('back_link' => 1 ));
		}
	 }
     
     register_activation_hook( __FILE__, 'ph_bookings_activation_check_for_customise_maximum_booking_per_slot_addon' );
     
	 //check if woocommerce exists
	 if ( !class_exists( 'woocommerce' ) || !class_exists('phive_booking_initialze_premium') ) {
		add_action( 'admin_init', 'Ph_Bookings_Customise_Maximum_Bookings_Per_Slot_deactivate' );
		if ( ! function_exists( 'Ph_Bookings_Customise_Maximum_Bookings_Per_Slot_deactivate' ) ) {
			function Ph_Bookings_Customise_Maximum_Bookings_Per_Slot_deactivate() {
				if ( !class_exists( 'woocommerce' ) || !class_exists('phive_booking_initialze_premium') ){
					deactivate_plugins( plugin_basename( __FILE__ ) );
					wp_safe_redirect( admin_url('plugins.php') );
				}
			}
		}
	 }

	 
if( ! class_exists('Ph_Bookings_Customise_Maximum_Bookings_Class') ) {
	class Ph_Bookings_Customise_Maximum_Bookings_Class {

		/**
		 * Constructor
		 */
		public function __construct() {
			$this->init();
            
            add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'plugin_action_links' ) );
		
			// add_action('wp_footer',array($this,'phive_booking_max_booking_scripts'));
	
			add_filter('ph_bookings_total_bookings_count', array($this, 'ph_bookings_get_total_bookings_count'), 10, 5);

			add_filter('ph_bookings_total_booking_availability', array($this, 'ph_bookings_modify_total_booking_availability'), 10, 5);			

			$this->found = false;
		}

		/**
		 * Init
		 */
		public function init(){
			if( ! class_exists('Ph_Bookings_Notification_Settings') )
				include_once 'includes/class-ph-bookings-max-bookings-settings.php';
		}

		public function ph_bookings_get_total_bookings_count($found,$product_id,$booked_detail,$date,$allowd_per_slot)
		{
			$this->found = $found;
			return $found;
		}

		public function ph_bookings_modify_total_booking_availability($availability, $product_id, $date,$booked_dates, $asset_id)
		{
			// error_log("date : ".$date);
			// error_log("date : ".date('Y-m-d H:i',$date));

			$rules=get_option(PH_MAX_BOOKINGS_SETTING_ID,false);
			$allowd_per_slot = get_post_meta( $product_id, '_phive_book_allowed_per_slot', 1 );
			// $max_of_minimum = $min_allowed_booking;

			// If no booking is there for the product.
			if($this->found === false)
			{
				$this->found = 0;	
			}

			if(!empty($rules) && ($this->found !== false) && empty($asset_id))
			{
				foreach ($rules as $key => $value) {
					if($value['product_id'] == $product_id )
					{
						if ($value['range_type'] == 'custom') 
						{
							if (!empty($value['from_date']) && !empty($value['to_date'])) 
							{
								$from_time = (isset($value['from_time']) && !empty($value['from_time'])) ? $value['from_time'] : '00:00';
								$to_time = (isset($value['to_time']) && !empty($value['to_time'])) ? $value['to_time'] : '23:59';

								$from_date = $value['from_date'].' '.$from_time;
								$to_date = $value['to_date'].' '.$to_time;

								// error_log($from_date);
								// error_log($to_date);

								if ($date >= strtotime($from_date) && $date <= strtotime($to_date)) 
								{
									if(!empty($value['max_booking']))
									{
										$availability = $value['max_booking']-$this->found;
										$this->found = false;
										$availability = max( 0, $availability );
										return $availability;
									}
								}
							}
						}
						else if ($value['range_type'] == 'months') 
						{
							if (!empty($value['from_month']) && !empty($value['to_month'])) 
							{
								// error_log(date('m', $date));
								if(((date('m', $date)) >= ($value['from_month'] + 1) ) && ((date('m', $date)) <= ($value['to_month'] + 1) ))
								{
									if (!empty($value['max_booking'])) 
									{
										$availability = $value['max_booking']-$this->found;
										$this->found = false;
										$availability = max( 0, $availability );
										return $availability;
									}
								}
							}
						}
						else if ($value['range_type'] == 'days') 
						{
							if (!empty($value['from_day']) && !empty($value['to_day'])) 
							{
								// error_log(date('N', $date));
								if((date('N', $date) >= $value['from_day'] ) && (date('N', $date) <= $value['to_day'] ) )
								{
									if (!empty($value['max_booking'])) 
									{
										$availability = $value['max_booking']-$this->found;
										$this->found = false;
										$availability = max( 0, $availability );
										return $availability;
									}
								}
							}
						}
						// error_log("value : ".print_r($value,1));
					}
				}
			}
			return $availability;
		}

		function plugin_action_links( $links ) {
		
			$plugin_links = array(
				'<a href="'.admin_url('admin.php?page=max-bookings-per-slot-settings').'" >' . __('Settings', 'bookings-and-appointments-for-woocommerce') . '</a>',
			);
			return array_merge( $plugin_links, $links );
		
		}

	}
}
new Ph_Bookings_Customise_Maximum_Bookings_Class();